+++
title = "Date and slug inheritance (Spanish)"
date = 2018-02-12
slug = "date-and-slug-inheritance"
tags = ["inheritance", "date", "slug"]
draft = false
+++

La herencia de fecha y slug es útil cuando desea usar los mismos datos
y slug para múltiples publicaciones, pero en diferentes idiomas.

[English version](/posts/en/data-and-slug-inheritance)
